@@ -1,8 +1,6 @@
-from connection import *
+from .connection import *
 
 
 __author__ = 'andprokofieff'
 __version__ = '0.0.1'
-__email__ = 'prokofieff.help@gmail.com'
-
-session()
\ No newline at end of file
+__email__ = 'prokofieff.help@gmail.com'
\ No newline at end of file
